#
# spec file for package ulfius
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2018-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
%define sover 2_7
Name:           ulfius
Version:        2.7.15
Release:        1.1
Summary:        Web Framework for REST Applications in C
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/babelouest/ulfius
Source:         https://github.com/babelouest/ulfius/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(jansson) >= 2.1
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libmicrohttpd) >= 0.9.51
BuildRequires:  pkgconfig(liborcania) >= 2.3.2
BuildRequires:  pkgconfig(libyder) >= 1.4.20
BuildRequires:  pkgconfig(zlib)

%description
The library is based on GNU libmicrohttpd for the backend web server, jansson
for the json manipulation library, and libcurl for the HTTP/SMTP client API.

It can be used to create web applications in C programs.

%package -n libulfius%{sover}
Summary:        Web Framework for REST Applications in C
Group:          System/Libraries

%description -n libulfius%{sover}
The library is based on GNU libmicrohttpd for the backend web server, jansson
for the json manipulation library, and libcurl for the HTTP/SMTP client API.

It can be used to create web applications in C programs.

%package devel
Summary:        Header files for ulfius
Group:          Development/Libraries/C and C++
Requires:       libcurl-devel
Requires:       libgnutls-devel
Requires:       libjansson-devel
Requires:       libmicrohttpd-devel
Requires:       libulfius%{sover} = %{version}
Requires:       orcania-devel
Requires:       yder-devel
Requires:       zlib-devel

%description devel
Development and header files for libulfius.

%package -n uwsc
Summary:        Ulfius WebSocket Client
Group:          Productivity/Networking/Web/Utilities

%description -n uwsc
A simple command-line websocket client program.

%prep
%setup -q

%build
%cmake \
    -DDOWNLOAD_DEPENDENCIES=OFF \
    -DCMAKE_SHARED_LINKER_FLAGS="" \
    -DCMAKE_INSTALL_PREFIX:PATH=/
%cmake_build

%install
%cmake_install
rm -rf %{buildroot}/%{_datadir}/doc/

%post   -n libulfius%{sover} -p /sbin/ldconfig
%postun -n libulfius%{sover} -p /sbin/ldconfig

%files -n libulfius%{sover}
%license LICENSE
%{_libdir}/libulfius.so.*

%files devel
%doc CHANGELOG.md README.md API.md
%{_includedir}/ulfius.h
%{_includedir}/ulfius-cfg.h
%{_libdir}/libulfius.so
%{_libdir}/cmake/Ulfius
%{_libdir}/pkgconfig/libulfius.pc

%files -n uwsc
%{_bindir}/uwsc
%{_mandir}/man1/uwsc.1%{?ext_man}

%changelog
* Sun Nov 19 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.15:
  * Add functions `ulfius_send_http_request_with_limit` and
    `ulfius_send_http_streaming_request_max_header`
  * cmake: restore option `WITH_YDER` which was forgotten in last
    release refactor
  * cmake: split package build options in 3 (tar.gz, deb and
    rpm), and set all packages build to off by default
* Mon Sep 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.14
  * Set protocols to http and https only in send requests.
  * Fix static analyzer warnings.
  * Minor improvements.
  * cmake: remove DownloadProject feature, now dependencies must
    be previously installed.
- Update to version 2.7.13
  * Websockets client: fix case where server sends a 0-length
    packet.
  * Minor improvements.
* Thu Jan 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.12
  * Improve cmake script.
  * Minor bugfixes
  * Add cmake build flag WITH_WEBSOCKET_MESSAGE_LIST to completely
    disable message lists storage in websockets.
* Sat Oct 15 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.11
  * Add ulfius_websocket_parse_json_message for incoming websocket
    messages
  * Breaking: in ulfius_websocket_send_json_message, return
    U_ERROR_PARAMS if j_message is NULL
  * Update callback examples
  * Fix minor bugs
* Sun May 29 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.10
  * Update `SameSite` cookie value, add `U_COOKIE_SAME_SITE_EMPTY`
    and allow value None
  * Fix pkg-config file with absolute path for
    `CMAKE_INSTALL_{INCLUDE,LIB}DIR`
  * Fix `CMAKE_MODULE_PATH` who was used as single value
* Tue Apr 19 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.7.9
  * Fix multipart/form-data for large values
  * Add option allowed_post_processor in struct _u_instance to
    disable post parameter processing depending on the content-type
  * Add more example_callbacks
* Sun Mar 13 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.8
  * Fix Origin header setting in websocket client
  * Remove header duplicates and Content-Length
  * Redirect libmicrohttpd logs to yder
  * Replace uint with unsigned int
  * Add ulfius_export_request_http and ulfius_export_response_http
  * Use o_strnullempty instead of o_strlen to check if a char * has
    data
* Thu Dec  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.7
  * Use `o_malloc` everywhere instead of `malloc`
* Fri Nov  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.6
  * Fix ulfius_websocket_wait_close
  * Fix ulfius_send_http_request when url contains spaces
* Wed Oct 27 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.5
  * Fix cookie management in ulfius_send_http_request and
    ulfius_send_http_streaming_request
  * Add option U_OPT_AUTH_BASIC to ulfius_set_request_properties
  * Fix bug in static_compressed_inmemory_website callback example
* Tue Sep  7 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.4
  Fix security issue CVE-2021-40540 (bsc#1190246)
  * Add void parameter to functions with no param.
  * Fix bug when malformed HTTP requests are sent.
  * Remove yder flag from libulfius.pc when yder is disabled.
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.3
  * Add ULFIUS_CHECK_VERSION macro.
  * Add struct _websocket_manager.keep_messages flag.
  * Add struct _u_response.free_shared_data and
    ulfius_set_response_shared_data.
* Thu Mar 11 2021 Martin Hauke <mardnh@gmx.de>
- Adjust BR: liborcania >= 2.1.1 is needed.
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.2
  * Fix post processor on multiple values with the same key.
  * Add missing check includes if tests are built.
  * Add option U_OPT_HTTP_URL_APPEND to
    ulfius_set_request_properties
  * Use ulfius_set_request_properties in example programs
* Sun Jan  3 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.1
  * Fix websocket protocol and extension management bug
  * Add Makefile flag UWSCFLAG to disable uwsc build
* Tue Dec  8 2020 Martin Hauke <mardnh@gmx.de>
- Add missing "Requires: zlib-devel" to ulfius-devel as
  ulfius.h includes zlib.h
* Mon Dec  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.0
  * Allow Content-Enconding header with ulfius_send_http_request
    to compress the response body
  * Add http_compression callback example
  * Add static_compressed_inmemory_website callback example
  * Add callback return value U_CALLBACK_IGNORE to igore
    incrementation of request->callback_position
  * Add ulfius_add_websocket_extension_message_perform and
    ulfius_add_websocket_client_extension_message_perform for
    advanced websocket extensions management
  * Add Compression Extensions for WebSocket
  * Fix lots of websocket bugs thanks to Autobahn|Testsuite.
* Wed Sep  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.9
  * Update doc generation
  * Add ulfius_websocket_send_json_message
  * Update pkg-config Libs with all dependencies
  * Add ulfius_global_init and ulfius_global_close
  * Rename U_STREAM_SIZE_UNKOWN to U_STREAM_SIZE_UNKNOWN,
    keep U_STREAM_SIZE_UNKOWN for backward compatibility
* Fri Jul 10 2020 Martin Hauke <mardnh@gmx.de>
- Redownloaded source tarball
* Tue Jul  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.8
  * Increase `ULFIUS_POSTBUFFERSIZE` to follow MHD documentation
  * Adapt code to be compatible with all MHD version
  * In case of secure websocket communication, use a combination of
    `gnutls_record_check_pending()` and `poll()` to determine if
    data is ready.
  * Install uwsc manpage
  * Fix bug about missing `res` variable assignment.
* Thu Jun  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.7
  * Check header property case insensitive in websocket client
  * Add libcurl option CURLOPT_NOPROGRESS in
    ulfius_send_http_streaming_request
  * Add ulfius_start_framework_with_mhd_options for expert mode
  * Fix websocket bugs
  * Add ulfius_set_request_properties and
    ulfius_set_response_properties
* Wed Apr  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.6
  * Update doc generation
  * Fix jansson memoy management bug
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.5
  * Allow `NULL` values on `struct _u_map`
  * Add function ulfius_send_smtp_rich_email to send e-mails
    with a specified content-type
  * Add follow_redirect in struct _u_request
  * Fix certificate check
* Mon Nov 18 2019 Martin Hauke <mardnh@gmx.de>
- Also add "libjansson-devel", "libgnutls-devel" and
  "libmicrohttpd-devel" as requirements for ulfius-devel
* Mon Nov 11 2019 Martin Hauke <mardnh@gmx.de>
- Disable LTO for now since it breaks compilation on i586
- Add "Requires: libcurl-devel" to ulfius-devel
* Sat Oct  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.4
  * Add precision for chunked response, got the inspiration
    from #132.
  * Update access token for oauth2 bearer validation callback
    function, add precision concerning libjwt.
  * Update callback_check_glewlwyd_access_token to the up-to-date
    version.
  * Various small fixes.
* Thu Aug  8 2019 Martin Hauke <mardnh@gmx.de>
- Add "Requires: yder-devel" to ulfius-devel
* Mon Aug  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.3
  * Fix warning appeared with gcc 9.1, fixes #128
  * Make instance->mhd_response_copy_data useless if MHD>=0.9.61
  * Fix MHD_start_daemon flag to reuse MHD_USE_THREAD_PER_CONNECTION
    by default
- Remove patch (fixed upstream):
  * 0001-Cast-option-value-for-curl_easy_setopt-on-CURLOPT_PO.patch
* Wed Jul 31 2019 Martin Hauke <mardnh@gmx.de>
- Add "Requires: orcania-devel" to ulfius-devel
* Fri Jul 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.2
  * Fix memory leak in `ulfius_set_string_body_request` and
    `ulfius_set_string_body_response`
  * Call callback function websocket_onclose_callback on all times,
    even if the websocket hasn't properly worked, so the calling
    program can avoid memory leak and broken resources, fix #126
- Add patch (fixes a compilation error on Tumbleweed):
  * 0001-Cast-option-value-for-curl_easy_setopt-on-CURLOPT_PO.patch
* Tue Jul  2 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.1
  * Fix package dependencies in cmake script
  * Fix core test to skip websocket tests if webscket is disabled
  * Disable ipv6 capabilities if libmicrohttpd is older than 0.9.52
  * Small bugfixes
- Update to version 2.6.0
  * Add struct _u_request->callback_position to know the position
    of the current callback in the callback list
  * Use MHD_USE_AUTO instead of MHD_USE_THREAD_PER_CONNECTION if
    libmicrohttpd is newer then 0.9.52
  * Add network_type in struct _u_instance and struct _u_request to
    specify IPV4, IPV6 or both networks
  * Add check_server_certificate_flag, check_proxy_certificate,
    check_proxy_certificate_flag and ca_path in struct _u_request to
    add more precision and control on SSL verification in u_send_request
  * Add functions ulfius_set_string_body_request,
    ulfius_set_binary_body_request, ulfius_set_empty_body_request
  * Add url_path in struct _u_request to store the url path only,
    without query parameters
  * Add ulfius_url_decode and ulfius_url_encode
  * Clean code, add more tests
    errors
  * Use gnutls_rnd() instead of rand()
- Update to version 2.5.5
  * Fix #121 where websockets messages of 126 or 127 bytes long made
  * Fix sneaky bug where endpoint injection inside a endpoint callback
    can lead to wrong callback calls, or even worse, crashes
* Sun Apr  7 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.4
  * Align PKGCONF_REQ_PRIVATE required versions
  * Backport ulfius_copy_request, ulfius_duplicate_request,
    ulfius_copy_response and ulfius_duplicate_response from Ulfius 2.6
* Sat Jan 12 2019 mardnh@gmx.de
- Update to version 2.5.3
  - Add flag to build Ulfius with GnuTLS support but without
    Websockets.
  - Fix CMake build process that didn't obviously linked Ulfius
    with pthreads.
* Fri Dec 28 2018 mardnh@gmx.de
- Update to version 2.5.2
  * Fix utf8 check on NULL value
- Update to version 2.5.1
  * Fix uwsc crash on some systems
- Update to version 2.5.0
  * Add struct _u_endpoint.check_utf8 to check all request parameters
    and values to be valid utf8 strings.
  * Add client certificate authentication for webservice and send
    request library.
  * Add support for SameSite attribute in response cookies
- Update to version 2.4.4
  * CMake scripts improvements
- Update to version 2.4.3
  * Add config file ulfius-cfg.h dynamically built with the options
  * Adapt examples with new ulfius-cfg.h file
- Update to version 2.4.2
  * Fix #79 where yuarel should be hidden from the outside world
- Update to version 2.4.1
  * Fix #78 where gnutls is not required if websocket is disabled
- Update to version 2.4.0
  * Fix Websocket fragmented messages
  * Fix CMake script that installed Orcania twice
  * Fix cppcheck warnings
  * Add timeout for http connections
  * Allow to use MHD_RESPMEM_MUST_COPY for different memory manager
  * Add websocket client framework
  * Add uwsc - Ulfius WebSocket Client
    A simple command-line websocket client program
- Remove patches (included/fixed upstream):
  * 0001-Fix-pkg-config-information-add-requires-fields-as-me.patch
  * ulfius-fix-cmake-path.patch
- Create subpackage "uwsc" for the Ulfius WebSocket Client program
* Sat Aug 11 2018 jengelh@inai.de
- Description update.
* Sun Jul 29 2018 mardnh@gmx.de
- Initial package, version 2.3.8
